@@ -27,6 +27,7 @@
 #include <dirent.h>
 #include <gnome.h>
 #include <games-frame.h>
+#include <games-card-selector.h>
 #include "cscmi.h"
 #include "sol.h"
 #include "menu.h"
@@ -36,6 +37,7 @@
 
 static GtkWidget *hint_dlg = NULL;
 static GtkWidget* seed_entry;
+static GtkTreeIter selected_iter;
 
 void show_game_over_dialog() {
   GtkWidget* dialog;
@@ -60,7 +62,6 @@ void show_game_over_dialog() {
                           _("New Game"), GTK_RESPONSE_ACCEPT,
                           GTK_STOCK_QUIT, GTK_RESPONSE_REJECT,
                           NULL);
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
   /* add a stock icon? */ 
@@ -108,16 +109,32 @@ static void select_game (GtkWidget *app, gint response, gpointer data)
   gtk_widget_hide(app);
 }
 
-static gboolean 
-select_double_click (GtkWidget * widget, GdkEventButton * event, gpointer dialog)
+static void
+select_double_click (GtkWidget *widget, GtkTreePath *path,
+                     GtkTreeViewColumn *column, gpointer dialog)
 {
   /* Handle a double click by faking a click on the OK button. */
-  if (event->type == GDK_2BUTTON_PRESS) {
-    select_game (GTK_WIDGET (dialog), GTK_RESPONSE_OK, NULL);
-  }
+  select_game (GTK_WIDGET (dialog), GTK_RESPONSE_OK, NULL);
+}
 
-  return FALSE;
-} 
+static void build_list (gchar * filename, GtkWidget * list)
+{
+  gchar *text;
+  GtkTreeIter iter;
+
+  if (g_utf8_collate (filename, "sol.scm") == 0)
+    return;
+
+  text = game_file_to_name (filename);
+  gtk_list_store_append (GTK_LIST_STORE (list), &iter);
+  gtk_list_store_set(GTK_LIST_STORE (list), 
+                     &iter, 0, text, 1,
+                     filename, -1);
+  if (g_utf8_collate(text,game_name) == 0) {
+    memcpy (&selected_iter, &iter, sizeof(GtkTreeIter));
+  }
+  g_free (text);
+}
 
 void show_select_game_dialog() 
 {
@@ -130,15 +147,13 @@ void show_select_game_dialog()
   GtkTreeViewColumn* column;
   GtkCellRenderer* renderer;
   GtkTreeIter iter;
-  GtkTreeIter selected_iter;
   GtkTreePath * path;
-  
-  guint i;
+  GamesFileList * files;
   gchar buf[20];
 
   if (waiting_for_mouse_up()) return;
 
-  if(!dialog) {
+  if (!dialog) {
 
     GtkWidget* label;
     GtkWidget* hbox;
@@ -175,15 +190,15 @@ void show_select_game_dialog()
                                                       "text", 0,
                                                       NULL);
     
-    gtk_tree_view_append_column(GTK_TREE_VIEW (list_view), column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
     
     select = gtk_tree_view_get_selection(GTK_TREE_VIEW (list_view));
     gtk_tree_selection_set_mode (select, GTK_SELECTION_BROWSE); 
 
     g_signal_connect (G_OBJECT (select), "changed", 
                       G_CALLBACK (select_rules), NULL);
-    g_signal_connect (G_OBJECT (list_view), "button_press_event",
-		      G_CALLBACK (select_double_click), (gpointer) dialog);
+    g_signal_connect (G_OBJECT (list_view), "row-activated",
+		      G_CALLBACK (select_double_click), dialog);
 
     scrolled_window = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
@@ -203,18 +218,12 @@ void show_select_game_dialog()
     filename = NULL;
     selected_iter.stamp = 0;
     
-    for(i = 0; i < n_games; i++) {
-	    gchar *text;
-	    text = game_file_to_name (game_dents[i]->d_name);
-	    gtk_list_store_append (GTK_LIST_STORE (list), &iter);
-            gtk_list_store_set(GTK_LIST_STORE (list), 
-                               &iter, 0, text, 1,
-                               game_dents[i]->d_name, -1);
-            if (g_utf8_collate(text,game_name) == 0) {
-                    memcpy (&selected_iter, &iter, sizeof(GtkTreeIter));
-            }
-            g_free (text);
-    }
+    files = games_file_list_new ("*.scm", gamesdir, NULL);
+    games_file_list_transform_basename (files);
+ 
+    games_file_list_for_each (files, (GFunc) build_list, list);
+
+    g_free (files);
 
     gtk_dialog_set_default_response ( GTK_DIALOG (dialog), GTK_RESPONSE_OK );
 
@@ -321,7 +330,6 @@ void show_hint_dialog()
 	                                   GTK_MESSAGE_INFO,
 	                                   GTK_BUTTONS_OK,
 	                                   gmessage);
-  gtk_dialog_set_has_separator (GTK_DIALOG (hint_dlg), FALSE);
   if (hint_dlg) {
 	  g_signal_connect (GTK_OBJECT (hint_dlg),
 			      "destroy",
@@ -338,22 +346,22 @@ void show_hint_dialog()
 static GtkWidget * deck_edit = NULL;
 
 static void 
-property_apply (GtkWidget *w, gpointer data)
+property_apply (GtkWidget *w, gchar * name, gpointer data)
 {
-  gtk_object_destroy (card_deck);
-  deck_options =  
-    gtk_card_deck_options_edit_get (GTK_CARD_DECK_OPTIONS_EDIT (w));
-  card_deck = gdk_card_deck_new (app->window, deck_options);
-  gconf_client_set_string (gconf_client, "/apps/aisleriot/card_options",
-                           deck_options, NULL);
+  gconf_client_set_string (gconf_client, THEME_GCONF_KEY, name, NULL);
+  /* Inconvenient fact of the day: the string "name" is in fact owned by 
+   * something that could go away. We have conveniently arranged so that it
+   * doesn't, but card_style should probably be removed as a variable. */
+  card_style = name;
 
+  set_card_theme (name);
+  
   refresh_screen();
 }
 
 void show_preferences_dialog () 
 {
   static GtkWidget* property_box = NULL;
-  GtkWidget * frame;
   
   if (!property_box) {
     property_box = gtk_dialog_new ();
@@ -362,13 +370,9 @@ void show_preferences_dialog ()
     gtk_dialog_add_buttons(GTK_DIALOG(property_box),
                            GTK_STOCK_CLOSE, GTK_RESPONSE_OK, NULL);
     gtk_window_set_transient_for (GTK_WINDOW(property_box), GTK_WINDOW (app));
-
-    frame = games_frame_new (_("Card Style"));
-    
-    deck_edit = gtk_card_deck_options_edit_new ();
-    gtk_container_add (GTK_CONTAINER (frame), deck_edit);
-    
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (property_box)->vbox), frame,
+     
+    deck_edit = games_card_selector_new (card_style);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (property_box)->vbox), deck_edit,
                         TRUE, TRUE, GNOME_PAD_SMALL);
     
     g_signal_connect (G_OBJECT (deck_edit), "changed",
@@ -383,9 +387,6 @@ void show_preferences_dialog ()
     gtk_widget_show_all (property_box);
   }
 
-  gtk_card_deck_options_edit_set (GTK_CARD_DECK_OPTIONS_EDIT (deck_edit),
-				  deck_options);
-  
   gtk_window_present (GTK_WINDOW (property_box));
 }
 
