@@ -33,6 +33,7 @@
 #include "statistics.h"
 
 static GtkWidget *about = NULL;
+static gchar * gamename = NULL;
 
 static void restart_game ()
 {
@@ -77,6 +78,7 @@ void help_about_callback ()
 	  "Jonathan Blandford (jrb@redhat.com)",
 	  "Felix Bellaby (felix@pooh.u-net.com)",
 	  "Rosanna Yuen (zana@webwynk.net)",
+	  "Callum McKenzie (callum@physics.otago.ac.nz)",
 	  "",
 	  N_("Card games:"),
 	  "Jonathan Blandford (jrb@redhat.com)",
@@ -136,6 +138,11 @@ void help_about_callback ()
   return;
 }
 
+static void help_on_specific_game ()
+{
+  gnome_help_display ("aisleriot.xml", gamename, NULL);
+}
+
 static void toolbar_show (void)
 {
   GtkWidget * toolbar;
@@ -171,6 +178,17 @@ static void toolbar_toggle_callback(GtkWidget * togglebutton, gpointer data)
   }
 }
 
+static void clickmove_toggle_callback(GtkWidget * togglebutton, gpointer data)
+{
+  gboolean state;
+  
+  state = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (togglebutton));
+
+  click_to_move = state;
+  gconf_client_set_bool (gconf_client, "/apps/aisleriot/click_to_move", state,
+			 NULL);
+}
+
 GnomeUIInfo rules_sub_menu[] = {
   GNOMEUIINFO_END
 };
@@ -197,6 +215,9 @@ GnomeUIInfo view_menu[] = {
 GnomeUIInfo help_menu[] = {
   GNOMEUIINFO_HELP("aisleriot"),
 
+  GNOMEUIINFO_ITEM_STOCK ("", "", help_on_specific_game, 
+			  GNOME_STOCK_PIXMAP_HELP),
+
   GNOMEUIINFO_MENU_ABOUT_ITEM(help_about_callback, NULL),
 
   GNOMEUIINFO_END
@@ -214,27 +235,26 @@ GnomeUIInfo game_menu[] = {
 
   GNOMEUIINFO_SEPARATOR,
 
-  GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(undo_callback, NULL),
-
-  GNOMEUIINFO_MENU_REDO_MOVE_ITEM(redo_callback, NULL),
-
-  GNOMEUIINFO_MENU_HINT_ITEM(show_hint_dialog, NULL),
-  /*  GNOMEUIINFO_ITEM_STOCK(N_("_Properties..."), NULL, 
-      show_property_dialog, GNOME_STOCK_MENU_PREF), */
-
-  GNOMEUIINFO_SEPARATOR,
-#if 0
-  GNOMEUIINFO_MENU_SCORES_ITEM(show_global_stats_dialog, NULL),
-  /*  GNOMEUIINFO_ITEM_STOCK(N_("S_tatistics..."), NULL, 
-      show_global_stats_dialog, GNOME_STOCK_MENU_BOOK_BLUE), */
-
-  GNOMEUIINFO_SEPARATOR,
-#endif
   GNOMEUIINFO_MENU_EXIT_ITEM(quit_app, NULL),
 
   GNOMEUIINFO_END
 };
 
+GnomeUIInfo control_menu[] = {
+  
+  GNOMEUIINFO_TOGGLEITEM (N_("_Click to move"), N_("Use clicks instead of drags to move cards"),
+                          clickmove_toggle_callback, NULL),
+
+  GNOMEUIINFO_SEPARATOR,
+
+  GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(undo_callback, NULL),
+
+  GNOMEUIINFO_MENU_REDO_MOVE_ITEM(redo_callback, NULL),
+
+  GNOMEUIINFO_MENU_HINT_ITEM(show_hint_dialog, NULL),
+
+  GNOMEUIINFO_END
+};
 
 GnomeUIInfo top_menu[] = {
 
@@ -242,6 +262,8 @@ GnomeUIInfo top_menu[] = {
 
   GNOMEUIINFO_MENU_VIEW_TREE(view_menu),
 
+  GNOMEUIINFO_SUBTREE (N_("_Control"), control_menu),
+
   GNOMEUIINFO_MENU_HELP_TREE(help_menu),
 
   GNOMEUIINFO_END
@@ -274,16 +296,35 @@ GnomeUIInfo toolbar[] =
 
 void undo_set_sensitive (gboolean state)
 {
-  gtk_widget_set_sensitive (game_menu[5].widget, state);
+  gtk_widget_set_sensitive (control_menu[2].widget, state);
   gtk_widget_set_sensitive (toolbar[4].widget, state);
 }
 
 void redo_set_sensitive (gboolean state)
 {
-  gtk_widget_set_sensitive (game_menu[6].widget, state);
+  gtk_widget_set_sensitive (control_menu[3].widget, state);
   gtk_widget_set_sensitive (toolbar[5].widget, state);
 }
 
+void help_update_game_name (gchar * name)
+{
+  static GnomeUIInfo newitems[] = { GNOMEUIINFO_ITEM_STOCK ("", 
+							  N_("View help for the current game"), 
+							  help_on_specific_game,
+							    GTK_STOCK_HELP),
+				    GNOMEUIINFO_END };
+  
+  if (gamename)
+    g_free (gamename);
+
+  gamename = g_strdup (name);
+
+  newitems[0].label = gamename;
+
+  gnome_app_remove_menu_range (GNOME_APP(app), "Help/Contents", 1, 1);
+  gnome_app_insert_menus (GNOME_APP(app), "Help/Contents", &newitems[0]);
+}
+
 void create_menus ()
 {
   gnome_app_create_menus (GNOME_APP(app), top_menu);
@@ -293,6 +334,12 @@ void create_menus ()
                                   gconf_client_get_bool (gconf_client,
                                                          "/apps/aisleriot/show_toolbar",
                                                          NULL));
+
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (control_menu[0].widget),
+                                  gconf_client_get_bool (gconf_client,
+                                                         "/apps/aisleriot/click_to_move",
+                                                         NULL));
+  
 }
 
 void install_menu_hints (GnomeApp *app)
