@@ -66,7 +66,7 @@ struct _GnobotsProperties {
   gboolean super_safe_moves;
   gboolean sound;
   gboolean splats;
-  gchar    *background_color;
+  GdkColor bgcolour;
   gint     selected_graphics;
   gint     selected_config;
   gint     keys[12];
@@ -119,7 +119,7 @@ static GConfClient *gconf_client;
 /**********************************************************************/
 static void apply_changes (void);
 static void apply_cb (GtkWidget*, gpointer);
-static void destroy_cb (GtkWidget*, gpointer);
+static gboolean delete_cb (GtkWidget*, gpointer);
 static void fill_property_list (void);
 static void pmap_selection (GtkWidget*, gpointer);
 static void type_selection (GtkWidget*, gpointer);
@@ -130,6 +130,7 @@ static void keypad_cb (GtkWidget*, GdkEventKey*, gpointer);
 static void defkey_cb (GtkWidget*, gpointer);
 static void fill_typemenu (GtkWidget*);
 static void fill_pmapmenu (GtkWidget*);
+static void gconf_set_background_color (GdkColor * c);
 /**********************************************************************/
 
 
@@ -167,6 +168,7 @@ apply_cb (GtkWidget *w, gpointer data)
   apply_changes ();
 
   gtk_widget_destroy (propbox);
+  list_view = NULL;
   propbox = NULL;
 }
 
@@ -179,10 +181,13 @@ apply_cb (GtkWidget *w, gpointer data)
  * Description:
  * handles property-box destruction messages
  **/
-static void
-destroy_cb (GtkWidget *w, gpointer data)
+static gboolean
+delete_cb (GtkWidget *w, gpointer data)
 {
+  list_view = NULL;
   propbox = NULL;
+
+  return FALSE;
 }
 
 
@@ -479,7 +484,7 @@ fill_property_list (void)
 static void
 pmap_selection (GtkWidget *widget, gpointer data)
 {
-  gint num = (gint)data;
+  gint num = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
   properties.selected_graphics = num;
 
@@ -501,7 +506,7 @@ pmap_selection (GtkWidget *widget, gpointer data)
 static void
 type_selection (GtkWidget *widget, gpointer data)
 {
-  gint num = (gint)data;
+  gint num = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
   properties.selected_config = num;
   fill_property_list ();
@@ -589,7 +594,7 @@ static void
 keypad_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
   gint keyval = event->keyval;
-  gint knum = (gint)data;
+  gint knum = GPOINTER_TO_INT(data);
 
   keyval = keyboard_preferred (keyval);
 
@@ -639,7 +644,6 @@ defkey_cb (GtkWidget *widget, gpointer data)
 static void
 fill_typemenu (GtkWidget *menu)
 {
-  GtkWidget *item;
   gint i;
 
 #if 0
@@ -656,14 +660,10 @@ fill_typemenu (GtkWidget *menu)
 #endif
 
   for (i = 0; i < num_game_configs (); ++i){
-    item = gtk_menu_item_new_with_label (_(game_config_name (i)));
-    gtk_widget_show (item);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-    g_signal_connect (G_OBJECT (item), "activate",
-                      G_CALLBACK (type_selection), (gpointer)i);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(game_config_name (i)));
   }
 
-  gtk_menu_set_active (GTK_MENU (menu), properties.selected_config);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (menu), properties.selected_config);
 }
 
 
@@ -677,7 +677,6 @@ fill_typemenu (GtkWidget *menu)
 static void
 fill_pmapmenu (GtkWidget *menu)
 {
-  GtkWidget *item;
   gint i;
 
 #if 0
@@ -695,34 +694,23 @@ fill_pmapmenu (GtkWidget *menu)
 #endif
 
   for (i = 0; i < num_game_graphics (); ++i) {
-    item = gtk_menu_item_new_with_label (_(game_graphics_name (i)));
-    gtk_widget_show (item);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-    g_signal_connect (G_OBJECT (item), "activate",
-                      G_CALLBACK (pmap_selection), (gpointer)i);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (menu),
+                               _(game_graphics_name (i)));
   }
 
-  gtk_menu_set_active (GTK_MENU (menu), properties.selected_graphics);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (menu),
+                            properties.selected_graphics);
 
 }
 
 static void
 bg_color_callback (GtkWidget *widget, gpointer data)
 {
-  gchar *tmp;
-  guint8 r, g, b, a;
-
-  gnome_color_picker_get_i8 (GNOME_COLOR_PICKER (widget),
-                             &r, &g, &b, &a);
-  
-  tmp = g_strdup_printf ("#%02x%02x%02x", r, g, b);
-  
-  set_background_color_from_name (tmp);
+  gtk_color_button_get_color (GTK_COLOR_BUTTON (widget),
+                              &properties.bgcolour);  
+  set_background_color (properties.bgcolour);
   clear_game_area ();
-  if (properties.background_color)
-    g_free (properties.background_color);
-  properties.background_color = tmp;
-  gconf_set_background_color (tmp);
+  gconf_set_background_color (&properties.bgcolour);
 }
 
 static void
@@ -750,13 +738,13 @@ show_properties_dialog (void)
   GtkWidget *vbox;
   GtkWidget *typemenu;
   GtkWidget *pmapmenu;
-  GtkWidget *menu;
   GtkWidget *chkbox;
   GtkWidget *table;
   GtkWidget *dbut;
   GtkWidget *scrolled;
   GtkWidget *frame;
   GtkWidget *w;
+  GtkTooltips *tooltips;
   GtkListStore *list;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
@@ -770,6 +758,8 @@ show_properties_dialog (void)
   if (propbox) 
     return;
 
+  tooltips = gtk_tooltips_new ();
+
   propbox = gtk_dialog_new_with_buttons (_("GNOME Robots Preferences"),
                                          GTK_WINDOW  (app),
                                          GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -797,10 +787,10 @@ show_properties_dialog (void)
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
 
   if (game_state == STATE_NOT_PLAYING) {
-    typemenu = gtk_option_menu_new ();
-    menu = gtk_menu_new ();
-    fill_typemenu (menu);
-    gtk_option_menu_set_menu (GTK_OPTION_MENU (typemenu), menu);
+    typemenu = gtk_combo_box_new_text ();
+    g_signal_connect (G_OBJECT (typemenu), "changed",
+                      G_CALLBACK (type_selection), NULL);
+    fill_typemenu (typemenu);
     gtk_box_pack_start_defaults (GTK_BOX (hbox), typemenu);
 
     list = gtk_list_store_new (NCOLS,
@@ -865,31 +855,43 @@ show_properties_dialog (void)
     g_signal_connect (G_OBJECT (chkbox), "clicked",
                       (GtkSignalFunc)safe_cb, NULL);
     gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 0, 1, 0, 1);
+    gtk_tooltips_set_tip (tooltips, chkbox,
+			  _("Prevent some dangerous moves"), 
+			  _("Prevent accidental moves that result in getting killed."));
 
     chkbox = gtk_check_button_new_with_label (_("Use super safe moves"));
     GTK_TOGGLE_BUTTON (chkbox)->active = properties.super_safe_moves;
     g_signal_connect (G_OBJECT (chkbox), "clicked",
                       (GtkSignalFunc)super_safe_cb, NULL);
     gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 0, 1, 1, 2);
+    gtk_tooltips_set_tip (tooltips, chkbox,
+			  _("Prevent all dangerous moves"), 
+			  _("Prevents all moves that result in getting killed."));
 
     chkbox = gtk_check_button_new_with_label (_("Enable sounds"));
     GTK_TOGGLE_BUTTON (chkbox)->active = properties.sound;
     g_signal_connect (G_OBJECT (chkbox), "clicked",
                       (GtkSignalFunc)sound_cb, NULL);
     gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 1, 2, 0, 1);
+    gtk_tooltips_set_tip (tooltips, chkbox,
+			  _("Play sounds for major events"), 
+			  _("Play sounds for events like winning a level and dying."));
 
     chkbox = gtk_check_button_new_with_label (_("Enable splats"));
     GTK_TOGGLE_BUTTON (chkbox)->active = properties.splats;
     g_signal_connect (G_OBJECT (chkbox), "clicked",
                       (GtkSignalFunc)splat_cb, NULL);
     gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 1, 2, 1, 2);
+    gtk_tooltips_set_tip (tooltips, chkbox,
+			  _("Play a sound when two robots collide"), 
+			  _("Play the most common, and potentially the most annoying, sound."));
 
   } else {
     label = gtk_label_new (_("You Cannot Change the Game Type When Playing"));
     gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
 
   }
-  label = gtk_label_new_with_mnemonic (_("_Game"));
+  label = gtk_label_new_with_mnemonic (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), cpage, label);
 
 
@@ -910,28 +912,24 @@ show_properties_dialog (void)
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
   gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
-  pmapmenu = gtk_option_menu_new ();
-  menu = gtk_menu_new ();
-  fill_pmapmenu (menu);
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (pmapmenu), menu);
+  pmapmenu = gtk_combo_box_new_text ();
+  g_signal_connect (G_OBJECT (pmapmenu), "changed",
+                    G_CALLBACK (pmap_selection), NULL);
+  fill_pmapmenu (pmapmenu);
   gtk_table_attach_defaults (GTK_TABLE (table), pmapmenu, 1, 2, 0, 1);
 
-  label = gtk_label_new (_("Background Color:"));
+  label = gtk_label_new (_("Background color:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
   gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
 
-  {
-    int ur, ug, ub;
-    
-    w  = gnome_color_picker_new ();
-    sscanf (properties.background_color, "#%02x%02x%02x", &ur, &ug, &ub);
-    gnome_color_picker_set_i8 (GNOME_COLOR_PICKER (w), ur, ug, ub, 0);
-    g_signal_connect (G_OBJECT (w), "color_set",
-                      G_CALLBACK (bg_color_callback), NULL);
-  }
+  w  = gtk_color_button_new ();
+  gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &properties.bgcolour);
+  g_signal_connect (G_OBJECT (w), "color_set",
+                    G_CALLBACK (bg_color_callback), NULL);
+
   gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 1, 2);
 
-  label = gtk_label_new_with_mnemonic (_("_Appearance"));
+  label = gtk_label_new_with_mnemonic (_("Appearance"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), gpage, label);
 
   /* The keyboard page */
@@ -963,7 +961,7 @@ show_properties_dialog (void)
                       keylayoutx[i]+1 , keylayoutx[i]+2, keylayouty[i],
                       keylayouty[i]+1, GTK_FILL, GTK_FILL, 3, 3);
     g_signal_connect (G_OBJECT (etext[i]), "key_press_event",
-                      G_CALLBACK (keypad_cb), (gpointer)i);
+                      G_CALLBACK (keypad_cb), GINT_TO_POINTER(i));
     g_signal_connect (G_OBJECT (key_labels[i]), "clicked",
                       G_CALLBACK (enable_entry_cb), etext[i]);
   }
@@ -1019,9 +1017,9 @@ show_properties_dialog (void)
   hbox = gtk_hbox_new (TRUE, GNOME_PAD);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
 
-  dbut = gtk_button_new_with_label (_("Use Standard Robots Keys"));
+  dbut = gtk_button_new_with_label (_("Use the Keypad"));
   g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys1);  
+                    G_CALLBACK (defkey_cb), (gpointer)default_keys3);  
   gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
 
   dbut = gtk_button_new_with_label (_("Use Left Hand Keys"));
@@ -1029,17 +1027,17 @@ show_properties_dialog (void)
                     G_CALLBACK (defkey_cb), (gpointer)default_keys2);  
   gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
 
-  dbut = gtk_button_new_with_label (_("Use the Keypad"));
+  dbut = gtk_button_new_with_label (_("Use Original Robots Keys"));
   g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys3);  
+                    G_CALLBACK (defkey_cb), (gpointer)default_keys1);  
   gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
 
-  label = gtk_label_new_with_mnemonic (_("_Keyboard"));
+  label = gtk_label_new_with_mnemonic (_("Keyboard"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), kpage, label);
 
 
-  g_signal_connect  (G_OBJECT  (propbox), "destroy",
-                     G_CALLBACK (destroy_cb), NULL);
+  g_signal_connect  (G_OBJECT  (propbox), "delete_event",
+                     G_CALLBACK (delete_cb), NULL);
   g_signal_connect (G_OBJECT (propbox), "response",
                     G_CALLBACK (apply_cb), NULL);
 
@@ -1081,6 +1079,7 @@ load_properties (void)
   gchar *cname = NULL;
   gint i;
   gchar *str;
+  gchar * bgcolour;
 
   for (i = 0; i < 12; i++) {
     properties.keys[i] = default_keys1[i];
@@ -1092,15 +1091,18 @@ load_properties (void)
       properties.keys[i] = gdk_keyval_from_name (str);
     }
     if ((str == NULL) || (properties.keys[i] == GDK_VoidSymbol)) {
-      properties.keys[i] = default_keys1[i];
+      properties.keys[i] = default_keys3[i];
     }
     g_free (str);
   }
 
-  properties.background_color = gconf_client_get_string (get_gconf_client (),
-                                                         KEY_BACKGROUND_COLOR, NULL);
-  if (properties.background_color == NULL)
-    properties.background_color = g_strdup ("#7590AE");
+  bgcolour = gconf_client_get_string (get_gconf_client (),
+                                      KEY_BACKGROUND_COLOR, NULL);
+  if (bgcolour == NULL)
+    bgcolour = g_strdup ("#7590AE");
+  
+  gdk_color_parse (bgcolour, &properties.bgcolour);
+  set_background_color (properties.bgcolour);
   
   sname = gconf_client_get_string (get_gconf_client (), KEY_THEME, NULL);
   if (sname == NULL)
@@ -1137,7 +1139,6 @@ load_properties (void)
   properties.splats = gconf_client_get_bool (get_gconf_client (),
                                              KEY_ENABLE_SPLATS, NULL);
 
-  set_background_color_from_name (properties.background_color);
   set_game_graphics (properties.selected_graphics);
   set_game_config (properties.selected_config);
   keyboard_set (properties.keys);
@@ -1152,11 +1153,17 @@ gconf_set_theme (gchar *value)
                            value, NULL);
 }
 
-void
-gconf_set_background_color (gchar *value)
+static void
+gconf_set_background_color (GdkColor * c)
 {
+  gchar * name;
+
+  name = g_strdup_printf ("#%04x%04x%04x", c->red, c->green, c->blue);
+  
   gconf_client_set_string (get_gconf_client (), KEY_BACKGROUND_COLOR,
-                           value, NULL);
+                           name, NULL);
+
+  g_free (name);
 }
 
 void
